% function fd = fdread(filename)
%
% incomplete as of yet.  only does rasters
%
% fd.rasters = Nx4 array containing rasternum, depint, timestamps, and masks, 
%              and depints
% fd.nrasters
% fd.epoch = in milliseconds
%
% NOTE: If a trial generated no spikes, it will be represented as a single
%       row of the fd.rasters whose spike time is -1.

function fd = fdread(filename)

[s,w] = unix(['xdview -rasters ' filename ' 2>/dev/null']);
if(s~=0)
  filename = cat(2,filename,'.gz');
  [s,w] = unix(['xdview -rasters ' filename ' 2>/dev/null']);
end

w = str2num(w);
fd.rasters = w(2:end,:);
fd.nrasters = w(1,1);
fd.epoch = w(1,2)/10000;
